@@ -1,60 +1,41 @@
-#' Launch Radiant in the default browser
+#' Launch radiant in the default browser
 #'
 #' @details See \url{https://radiant-rstats.github.io/docs} for documentation and tutorials
 #'
-#' @examples
-#' \dontrun{
-#' radiant::radiant()
-#' }
-#' @export
-radiant <- function() {
-  message("Starting Radiant ...")
-  if (!"package:radiant" %in% search()) {
-    if (!suppressMessages(require(radiant)))
-      stop("Calling radiant start function but radiant is not installed.")
-  }
-  shiny::runApp(system.file("app", package = "radiant"), launch.browser = TRUE)
-}
-
-#' Update Radiant
+#' @importFrom radiant.data launch
 #'
 #' @examples
 #' \dontrun{
-#' radiant::update_radiant()
+#' radiant()
 #' }
-#'
 #' @export
-update_radiant <- function() {
+radiant <- function() radiant.data::launch(package = "radiant", run = "browser")
 
-  message("Updating Radiant ...")
-  ## cleanup old session files
-  unlink("~/radiant.sessions/*.rds", force = TRUE)
+#' Launch radiant in an Rstudio window
+#'
+#' @details See \url{https://radiant-rstats.github.io/docs} for documentation and tutorials
+#'
+#' @importFrom radiant.data launch
+#'
+#' @examples
+#' \dontrun{
+#' radiant_window()
+#' }
+#' @export
+radiant_window <- function() radiant.data::launch(package = "radiant", run = "window")
 
-  os_type <- Sys.info()["sysname"]
-  type <- ifelse (os_type == "Linux", "source", "binary")
-
-  ## avoid problems with loaded packages, new.packages added for windoze
-  system(paste0(Sys.which("R"), " -e \"install.packages('radiant', repos = 'https://radiant-rstats.github.io/minicran', type = '", type, "'); update.packages(lib.loc = .libPaths()[1], repos = 'https://radiant-rstats.github.io/minicran', ask = FALSE, type = '", type, "'); pkgs <- new.packages(lib.loc = .libPaths()[1], repos = 'https://radiant-rstats.github.io/minicran', type = '", type, "', ask = FALSE); if (length(pkgs) > 0) install.packages(pkgs, repos = 'https://radiant-rstats.github.io/minicran', type = '", type, "')\""))
-
-  ## strange behavior on windows using cmd below
-  # cmd <- paste0("install.packages('radiant', repos = 'https://radiant-rstats.github.io/minicran', type = '", type, "'); update.packages(lib.loc = .libPaths()[1], repos = 'https://radiant-rstats.github.io/minicran', ask = FALSE, type = '", type, "'); pkgs <- new.packages(lib.loc = .libPaths()[1], repos = 'https://radiant-rstats.github.io/minicran', type = '", type, "', ask = FALSE); if (length(pkgs) > 0) install.packages(pkgs, repos = 'https://radiant-rstats.github.io/minicran', type = '", type, "')")
-
-  ## restart R(studio) with a command to avoid having to unload libraries that
-  ## are blocking the update (i.e., "unable to remove" error)
-  cmd <- ""
-  if (os_type == "Windows") {
-    pkgs <- new.packages(lib.loc = .libPaths()[1], repos = "https://radiant-rstats.github.io/minicran", type = "binary", ask = FALSE)
-    if (length(pkgs) > 0) {
-      cmd <- paste0("install.packages(c('", paste0(pkgs, collapse = "', '"), "'), repos = 'https://radiant-rstats.github.io/minicran', type = 'binary')")
-    }
-  }
-
-  ## message to alternative update command, temporary fail-safe
-  message("Alternative update command:\n\nsource('https://raw.githubusercontent.com/radiant-rstats/minicran/gh-pages/build.R')")
-
-  ## Restarting Rstudio session from http://stackoverflow.com/a/25934774/1974918
-  ret <- .rs.restartR(cmd)
-}
+#' Launch radiant in the Rstudio viewer
+#'
+#' @details See \url{https://radiant-rstats.github.io/docs} for documentation and tutorials
+#'
+#' @importFrom radiant.data launch
+#'
+#' @examples
+#' \dontrun{
+#' radiant_viewer()
+#' }
+#' @export
+radiant_viewer <- function() radiant.data::launch(package = "radiant", run = "viewer")
 
 #' Create a launcher and updater for Windows (.bat)
 #'
@@ -69,21 +50,21 @@ update_radiant <- function() {
 #'
 #' @export
 win_launcher <- function(app = c("radiant", "radiant.data", "radiant.design", "radiant.basics", "radiant.model", "radiant.multivariate")) {
-
   if (!interactive()) stop("This function can only be used in an interactive R session")
 
-  if (Sys.info()["sysname"] != "Windows")
+  if (Sys.info()["sysname"] != "Windows") {
     return(message("This function is for Windows only. For Mac use the mac_launcher() function"))
+  }
 
   answ <- readline("Do you want to create shortcuts for Radiant on your Desktop? (y/n) ")
-  if (substr(answ, 1, 1) %in% c("y","Y")) {
-
+  if (substr(answ, 1, 1) %in% c("y", "Y")) {
     local_dir <- Sys.getenv("R_LIBS_USER")
     if (!file.exists(local_dir)) dir.create(local_dir, recursive = TRUE)
 
-    pt <- file.path(Sys.getenv("HOME") ,"Desktop")
-    if (!file.exists(pt))
-      pt <- file.path(Sys.getenv("USERPROFILE") ,"Desktop", fsep = "\\")
+    pt <- file.path(Sys.getenv("HOME"), "Desktop")
+    if (!file.exists(pt)) {
+      pt <- file.path(Sys.getenv("USERPROFILE"), "Desktop", fsep = "\\")
+    }
 
     if (!file.exists(pt)) {
       pt <- Sys.getenv("HOME")
@@ -93,20 +74,21 @@ win_launcher <- function(app = c("radiant", "radiant.data", "radiant.design", "r
     pt <- normalizePath(pt, winslash = "/")
 
     fn1 <- file.path(pt, "radiant.bat")
-    launch_string <- paste0("\"",Sys.which('R'), "\" -e \"if (!require(radiant)) { install.packages('radiant', repos = 'https://radiant-rstats.github.io/minicran/', type = 'binary') }; library(radiant); shiny::runApp(system.file('app', package='", app[1], "'), port = 4444, launch.browser = TRUE)\"")
+    launch_string <- paste0("\"", Sys.which("R"), "\" -e \"if (!require(radiant)) { install.packages('radiant', repos = 'https://radiant-rstats.github.io/minicran/', type = 'binary') }; library(radiant); shiny::runApp(system.file('app', package='", app[1], "'), port = 4444, launch.browser = TRUE)\"")
     launch_string
     cat(launch_string, file = fn1, sep = "\n")
     Sys.chmod(fn1, mode = "0755")
 
     fn2 <- file.path(pt, "update_radiant.bat")
-    launch_string <- paste0("\"", Sys.which('R'), "\" -e \"unlink('~/r_sessions/*.rds', force = TRUE); install.packages('radiant', repos = 'https://radiant-rstats.github.io/minicran/', type = 'binary'); suppressWarnings(update.packages(lib.loc = .libPaths()[1], repos = 'https://radiant-rstats.github.io/minicran', ask = FALSE, type = 'binary'))\"\npause(1000)")
-    cat(launch_string, file = fn2,sep = "\n")
+    launch_string <- paste0("\"", Sys.which("R"), "\" -e \"unlink('~/r_sessions/*.rds', force = TRUE); install.packages('radiant', repos = 'https://radiant-rstats.github.io/minicran/', type = 'binary'); suppressWarnings(update.packages(lib.loc = .libPaths()[1], repos = 'https://radiant-rstats.github.io/minicran', ask = FALSE, type = 'binary'))\"\npause(1000)")
+    cat(launch_string, file = fn2, sep = "\n")
     Sys.chmod(fn2, mode = "0755")
 
-    if (file.exists(fn1) && file.exists(fn2))
+    if (file.exists(fn1) && file.exists(fn2)) {
       message("Done! Look for a file named radiant.bat on your desktop. Double-click it to start Radiant in your default browser. There is also a file called update_radiant.bat you can double click to update the version of Radiant on your computer.\n")
-    else
+    } else {
       message("Something went wrong. No shortcuts were created.")
+    }
   } else {
     message("No shortcuts were created.\n")
   }
@@ -124,34 +106,33 @@ win_launcher <- function(app = c("radiant", "radiant.data", "radiant.design", "r
 #' }
 #'
 #' @export
-mac_launcher <- function(app = c("radiant","radiant.data","radiant.design","radiant.basics","radiant.model","radiant.multivariate")) {
-
+mac_launcher <- function(app = c("radiant", "radiant.data", "radiant.design", "radiant.basics", "radiant.model", "radiant.multivariate")) {
   if (!interactive()) stop("This function can only be used in an interactive R session")
 
-  if (Sys.info()["sysname"] != "Darwin")
+  if (Sys.info()["sysname"] != "Darwin") {
     return(message("This function is for Mac only. For windows use the win_launcher() function"))
+  }
 
   answ <- readline("Do you want to create shortcuts for Radiant on your Desktop? (y/n) ")
-  if (substr(answ, 1, 1) %in% c("y","Y")) {
-
+  if (substr(answ, 1, 1) %in% c("y", "Y")) {
     local_dir <- Sys.getenv("R_LIBS_USER")
     if (!file.exists(local_dir)) dir.create(local_dir, recursive = TRUE)
 
-    fn1 <- paste0("/Users/",Sys.getenv("USER"),"/Desktop/radiant.command")
+    fn1 <- paste0("/Users/", Sys.getenv("USER"), "/Desktop/radiant.command")
     launch_string <- paste0("#!/usr/bin/env Rscript\nif (!require(radiant)) {\n  install.packages('radiant', repos = 'https://radiant-rstats.github.io/minicran/', type = 'binary')\n}\n\nlibrary(radiant)\nshiny::runApp(system.file('app', package='", app[1], "'), port = 4444, launch.browser = TRUE)\n")
     cat(launch_string, file = fn1, sep = "\n")
     Sys.chmod(fn1, mode = "0755")
 
-    fn2 <- paste0("/Users/",Sys.getenv("USER"),"/Desktop/update_radiant.command")
+    fn2 <- paste0("/Users/", Sys.getenv("USER"), "/Desktop/update_radiant.command")
     launch_string <- paste0("#!/usr/bin/env Rscript\nunlink('~/r_sessions/*.rds', force = TRUE)\ninstall.packages('radiant', repos = 'https://radiant-rstats.github.io/minicran/', type = 'binary')\nsuppressWarnings(update.packages(lib.loc = .libPaths()[1], repos = 'https://radiant-rstats.github.io/minicran', ask = FALSE, type = 'binary'))\nSys.sleep(1000)")
-    cat(launch_string, file = fn2, sep= "\n")
+    cat(launch_string, file = fn2, sep = "\n")
     Sys.chmod(fn2, mode = "0755")
 
-    if (file.exists(fn1) && file.exists(fn2))
+    if (file.exists(fn1) && file.exists(fn2)) {
       message("Done! Look for a file named radiant.command  on your desktop. Double-click it to start Radiant in your default browser. There is also a file called update_radiant.command you can double click to update the version of Radiant on your computer.\n")
-    else
+    } else {
       message("Something went wrong. No shortcuts were created.")
-
+    }
   } else {
     message("No shortcuts were created.\n")
   }
@@ -169,34 +150,33 @@ mac_launcher <- function(app = c("radiant","radiant.data","radiant.design","radi
 #' }
 #'
 #' @export
-lin_launcher <- function(app = c("radiant","radiant.data","radiant.design","radiant.basics","radiant.model","radiant.multivariate")) {
-
+lin_launcher <- function(app = c("radiant", "radiant.data", "radiant.design", "radiant.basics", "radiant.model", "radiant.multivariate")) {
   if (!interactive()) stop("This function can only be used in an interactive R session")
 
-  if (Sys.info()["sysname"] != "Linux")
+  if (Sys.info()["sysname"] != "Linux") {
     return(message("This function is for Linux only. For windows use the win_launcher() function and for mac use the mac_launcher() function"))
+  }
 
   answ <- readline("Do you want to create shortcuts for Radiant on your Desktop? (y/n) ")
-  if (substr(answ, 1, 1) %in% c("y","Y")) {
-
+  if (substr(answ, 1, 1) %in% c("y", "Y")) {
     local_dir <- Sys.getenv("R_LIBS_USER")
     if (!file.exists(local_dir)) dir.create(local_dir, recursive = TRUE)
 
-    fn1 <- paste0(Sys.getenv("HOME"),"/Desktop/radiant.sh")
+    fn1 <- paste0(Sys.getenv("HOME"), "/Desktop/radiant.sh")
     launch_string <- paste0("#!/usr/bin/env Rscript\nif (!require(radiant)) {\n  install.packages('radiant', repos = 'https://radiant-rstats.github.io/minicran/')\n}\n\nlibrary(radiant)\nshiny::runApp(system.file('app', package='", app[1], "'), port = 4444, launch.browser = TRUE)\n")
     cat(launch_string, file = fn1, sep = "\n")
     Sys.chmod(fn1, mode = "0755")
 
-    fn2 <- paste0(Sys.getenv("HOME"),"/Desktop/update_radiant.sh")
+    fn2 <- paste0(Sys.getenv("HOME"), "/Desktop/update_radiant.sh")
     launch_string <- paste0("#!/usr/bin/env Rscript\nunlink('~/r_sessions/*.rds', force = TRUE)\ninstall.packages('radiant', repos = 'https://radiant-rstats.github.io/minicran/')\nsuppressWarnings(update.packages(lib.loc = .libPaths()[1], repos = 'https://radiant-rstats.github.io/minicran', ask = FALSE))\nSys.sleep(1000)")
     cat(launch_string, file = fn2, sep = "\n")
     Sys.chmod(fn2, mode = "0755")
 
-    if (file.exists(fn1) && file.exists(fn2))
+    if (file.exists(fn1) && file.exists(fn2)) {
       message("Done! Look for a file named radiant.sh on your desktop. Double-click it to start Radiant in your default browser. There is also a file called update_radiant.sh you can double click to update the version of Radiant on your computer.\n\nIf the .sh files are opened in a text editor when you double-click them go to File Manager > Edit > Preferences > Behavior and click 'Run executable text files when they are opened'.")
-    else
+    } else {
       message("Something went wrong. No shortcuts were created.")
-
+    }
   } else {
     message("No shortcuts were created.\n")
   }
@@ -218,15 +198,15 @@ lin_launcher <- function(app = c("radiant","radiant.data","radiant.design","radi
 #' }
 #'
 #' @export
-launcher <- function(app = c("radiant","radiant.data","radiant.design","radiant.basics","radiant.model","radiant.multivariate")) {
-
+launcher <- function(app = c("radiant", "radiant.data", "radiant.design", "radiant.basics", "radiant.model", "radiant.multivariate")) {
   os <- Sys.info()["sysname"]
-  if (os == "Darwin")
+  if (os == "Darwin") {
     mac_launcher(app[1])
-  else if (os == "Windows")
+  } else if (os == "Windows") {
     win_launcher(app[1])
-  else if (os == "Linux")
+  } else if (os == "Linux") {
     lin_launcher(app[1])
-  else
+  } else {
     return(message("This function is not available for your platform."))
+  }
 }
